# logs/

This directory is for **captured stdout/stderr logs** from training, sweeps, and benchmarks.

- This folder is **ignored by git** (except this README).
- Prefer timestamped filenames (e.g. `psannlm_300m_20260115_120000.log`).

